/**
 * Copyright (C) 2003-2004 Funambol
 *
 *  This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
 */


package sync4j.framework.core;

/**
 * This class represents the &ltTarget&gt element as defined by the SyncML
 * representation specifications
 *
 * @author Stefano Fornari @ Funambol
 *
 * @version $Id: Target.java,v 1.1 2004/04/13 09:37:32 luigia Exp $
 */
public final class Target
implements java.io.Serializable {
    
    // ------------------------------------------------------------ Private data

    private String locURI;
    private String locName;

    // ------------------------------------------------------------ Constructors

    /**
     * For serialization purposes
     */
    protected Target() {}

    /**
     * Creates a new Target object with the given locURI and locName
     *
     * @param locURI the locURI - NOT NULL
     * @param locName the locName - NULL
     *
     */
    public Target( final String locURI, final String locName) {
        setLocURI(locURI);
        this.locName = locName;
    }

    /**
     * Creates a new Target object with the given locURI
     *
     * @param locURI the locURI - NOT NULL
     *
     */
    public Target(final String locURI) {
        this(locURI, null);
    }

    // ---------------------------------------------------------- Public methods
    
    /** Gets locURI properties
     * @return locURI properties
     */
    public String getLocURI() {
        return locURI;
    }

    /**
     * Sets locURI property
     * @param locURI the locURI
     */
    public void setLocURI(String locURI) {
        if (locURI == null) {
            throw new IllegalArgumentException("locURI cannot be null");
        }
        this.locURI = locURI;
    }

    /**
     * Gets locName properties
     * @return locName properties
     */
    public String getLocName() {
        return locName;
    }

    /**
     * Sets locName property
     * @param locName the locURI
     */
    public void setLocName(String locName) {
        this.locName = locName;
    }
}