/**
 * Copyright (C) 2003-2004 Funambol
 *
 *  This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
 */


package sync4j.framework.core;

/**
 * Corresponds to the &ltVerDTD&gt tag in the SyncML devinf DTD
 *
 * @author Stefano Fornari @ Funambol
 *
 * @version $Id: VerDTD.java,v 1.1 2004/04/13 09:37:32 luigia Exp $
 */
public final class VerDTD
implements java.io.Serializable {
    
    // ------------------------------------------------------------ Private data

    private String value;
    
    // ------------------------------------------------------------ Constructors

    /** For serialization purposes */
    protected VerDTD() {}
    
    /** 
     * Creates a new VerDTD object with the given value
     *
     * @param value the version - NOT NULL
     *
     */
    public VerDTD(final String value) {
        setValue(value);
    }
    
    // ---------------------------------------------------------- Public methods
    
    /** 
     * Gets value properties
     *
     * @return value properties
     */
    public String getValue() {
        return value;
    }
    
    /**
     * Sets the version of DTD
     *
     * @param value the version of DTD
     */
    public void setValue(String value) {
        if ((value == null) || (value.length() == 0)) {
            throw new IllegalArgumentException("value cannot be null or empty");
        }
        this.value = value;
    }
    
    /**
     * Compares the string value to the specified input object.
     *
     * @param object the object to be compared
     *
     * @return true if the specified input object equals the value of the
     *         VerDTD object
     * 
     */ 
    public boolean equals(Object obj) {
        if ((obj instanceof VerDTD) == false) {
            return false;
        }
        return (((VerDTD) obj).getValue().equals(value));
    }    
}