/**
 * Copyright (C) 2003-2004 Funambol
 *
 *  This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
 */


package sync4j.framework.core;

/**
 * This class represents the &lt;VerProto&gt; tag as defined by the SyncML r
 * epresentation specifications.
 *
 * @author Stefano Fornari @ Funambol
 *
 * @version $Id: VerProto.java,v 1.1 2004/04/13 09:37:32 luigia Exp $
 *
 */
public final class VerProto
implements java.io.Serializable {
    
    // ------------------------------------------------------------ Private data
    
    private String version;
    
    // ------------------------------------------------------------ Constructors
    
    /**
     * For serialization purposes
     */
    protected VerProto() {}
    
    /**
     * Creates a new VerProto object from its version.
     *
     * @param version the protocol version - NOT NULL
     *
     */
    public VerProto(final String version) {
        setVersion(version);
    }
    
    // ---------------------------------------------------------- Public methods
    
    /**
     * Returns the protocol version.
     * 
     * @return the protocol version - NOT NULL
     *
     */
    public String getVersion() {
        return version; 
    }
    
    /**
     * Sets the protol version.
     *
     * @param version the protocol version - NOT NULL
     *
     * @throws IllegalArgumentException if version is null
     */
    public void setVersion(String version) {
        if (version == null) {
            throw new IllegalArgumentException("version cannot be null");
        }
        this.version = version;
    }
    
    /**
     * Compares this object with a given ProtocolVersion object comparing the 
     * two versions.
     *
     * @return true if the two object represent the same information
     */
    public boolean equals(Object obj) {
        if ((obj instanceof VerProto) == false) {
            return false;
        }
        return (((VerProto) obj).getVersion().equals(this.version));
    }
}