/**
 * Copyright (C) 2003-2004 Funambol
 *
 *  This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
 */

package sync4j.framework.server;

import org.apache.commons.lang.builder.ToStringBuilder;


/**
 * Represents a synchronization timestamp for a particular database and principal.
 * <i>tag</i> stores the next (when used as a next timestamp) or the last (when 
 * used as a last timstamp) value as it appears in <i>SyncAnchor</i>.
 *
 * @author  Stefano Fornari @ Funambol
 * @version $Id: SyncTimestamp.java,v 1.2 2004/04/13 09:37:33 luigia Exp $
 */
public class SyncTimestamp {
    
    // ------------------------------------------------------------- Public data
    
    public long   start    = -1  ;  // timestamp of when sync started
    public long   end      = -1  ;  // timestamp of when sync ended
    public String tag       = null;  // the last/next tag
    
    // ------------------------------------------------------------ Constructors
    
    /** Creates a new instance of LastTimestamp */
    public SyncTimestamp() { }
    
    /** Creates a new instance of LastTimestamp */
    public SyncTimestamp(final String tag  , 
                         final long   start, 
                         final long   end  ) {
        this.tag      = tag      ;
        this.start    = start    ;
        this.end      = end      ;
    }
    
    // ---------------------------------------------------------- Public methods
    
    public String toString() {
        ToStringBuilder sb = new ToStringBuilder(this);
        
        sb.append("tag"      , tag).
           append("start"    , new java.sql.Timestamp(start)).
           append("end"      , new java.sql.Timestamp(end));
        return sb.toString();
    }
}